#!env python
# -*- coding: iso-8859-1 -*-
###########################################################################
# 
# File:            lockfile.py
#
# Licence:         Donationware, distributed as Freeware
#
#                  If you find this software useful to you and you would
#                  like to help the developer to maintain it also in the future, 
#                  please donate a small amount of your liking to the 
#                  PayPal account: olammi@iki.fi.
#
#                  This donation is not required to use the software and the 
#                  software is licenced as freeware.
#
#                  To individual and non-commercial use only! Script
#                  and source code may be used freely for non-commercial
#                  purposes. Any commercial usage requires permission or
#                  licence from the author. 
#
# Author:          Olli Lammi (olammi@iki.fi)
#
# Version:         1.0b
#
# Date:            22.09.2010
#
# Description:     Library to implement a lock file in Python.
#                  
# Requirements:    Python interpreter 2.4 or newer (www.python.org)
#                  (tested with 2.4.3)
# 
# Version history: ** 02.03.2009 v1.0a (Olli Lammi) **
#                  First version. 
#
#                  ** 22.08.2010 v1.0b (Olli Lammi) **
#                  Tries to remove the lockfile if the lock is older
#                  than 120 seconds. 
#
###########################################################################

# Imports

import sys, os, time

###########################################################################

# Constants

LOCK_LIFETIME = 120 

###########################################################################

# Classes

class LockFile:
    def __init__(self, fname):
        self.lockfilename = fname
        self.ihaveit = 0
        self.lockfile = None

    def lock(self):
        if self.ihaveit:
            return 1
        count = 0
        while not self.ihaveit:
            try:
                self.lockfile = os.open(self.lockfilename, os.O_CREAT | os.O_EXCL | os.O_WRONLY)
            except:
                self.lockfile = None
            if self.lockfile == None:
                count = count + 1                 
                if count > 10:
                    return 0
                try:
                    if count > 1 and (time.time() - os.stat(self.lockfilename).st_mtime) > LOCK_LIFETIME:
                        os.remove(self.lockfilename)
                except:
                    pass
                time.sleep(1)
            else:
                self.ihaveit = 1
                
        return self.ihaveit

    def free(self):
        if not self.ihaveit:
            return 0
        if self.lockfile != None:
            os.close(self.lockfile)
            self.lockfile = None
        try:
            os.remove(self.lockfilename)
        except:
            pass
        self.ihaveit = 0
        return 1

    def getName(self):
        return self.lockfilename
