#!env python
# -*- coding: iso-8859-1 -*-
###########################################################################
# 
# File:            oumanGetData.py
#
#
# Licence:         Donationware, distributed as Freeware
#
#                  If you find this software useful to you and you would
#                  like to help the developer to maintain it also in the future, 
#                  please donate a small amount of your liking to the 
#                  PayPal account: olammi@iki.fi.
#
#                  This donation is not required to use the software and the 
#                  software is licenced as freeware.
#
#                  To individual and non-commercial use only! Script
#                  and source code may be used freely for non-commercial
#                  purposes. Any commercial usage requires permission or
#                  licence from the author. 
#
#
HELP_TEXT = """
# Usage:           python oumanGetData.py --help
#                  python oumanGetData.py [-v] <serialDev> <id>
#
#                  Options (options override the configuration file):
#                    --help      - Prints out a help and exits.
#
#                    -v          - Enable debug/verbose logging.
#
#                  Parameters:
#                    serialDev   - Path to serial device (eg. /dev/ttyS0)
#
#                    id          - Data id.
#
#                  Examples:
#                    [taloLogger]% python ./oumanGetData.py /dev/ttyS0 45
#                    02 06 04 00 2D 00 01 38
#                    [taloLogger]%  
#
"""
#
# Author:          Olli Lammi (olammi@iki.fi)
#
# Version:         1.0a
#
# Date:            30.01.2011
#
# Functions:       -
#                   
# Description:     Script to read Ouman raw data using
#                  the serial connection to Ouman controller.
#
# Requirements:    Python interpreter 2.4 or newer (www.python.org)
#                  (tested with 2.4.4)
# 
#                  For Ouman controller communications:
#                    Python Serial Port Extension: pySerial  
#                    (http://pyserial.wiki.sourceforge.net/pySerial)
#
# Version history: ** 30.01.2011 v1.0a (Olli Lammi) **
#                  First beta version for testers. 
#
###########################################################################

# Imports

import sys, os 
import string  

import configuration
import oumanSerial
import log


####### main ##########################################################

def main():
    verbose = 0
    serial_port = ''
    ouman_id = -1

    # handle command line parameters
    i = 1
    j = 0
    while i < len(sys.argv):
        if sys.argv[i] == '--help':
            Help()
            sys.exit(1)
        elif sys.argv[i] == '-v':
            verbose = 1
        elif j == 0:
            serial_port = sys.argv[i]
            j = j + 1
        elif j == 1:
            ouman_id = sys.argv[i]
            j = j + 1
        else:
            Usage()
            sys.exit(1)

        i = i + 1
        
    if len(serial_port) <= 0 or len(ouman_id) <= 0:
        Usage()
        sys.exit(1) 

    ouman_id = int(ouman_id)

    conf = configuration.Configuration()
    conf.addConfigurable(log.Logger)
    conf.setValue('CONSOLE_LOGGING', 'true')
    if verbose:
        conf.setValue('VERBOSE_LOGGING', 'true')
    LOG = log.Logger(conf)
    log.Logging.setLogger(LOG)

    oser = oumanSerial.OumanSerial(serial_port, 'DEBUG')

    data = oser.runQueryId(ouman_id)

    if len(data) <= 0:
        LOG.log("ERROR: Cannot get data from Ouman device.")
        sys.exit(1)

    temps = ''
    for i in range(len(data)):
      temps = temps + ('%02X' % (ord(data[i]), )) + ' '

    print temps
    print repr(data)

    if ouman_id == 46:
        print 'Alarm data: '
        temp = oumanSerial.getOumanDataPart(data)[2:]
        print '    Location: %s' % (temp[0:6],)
        print '    Object id: %s' % (oumanSerial.convertOumanMessage(oumanSerial.TYPE_UINT16, 6, data), )
        print '    Alarm type: %s' % (oumanSerial.convertOumanMessage(oumanSerial.TYPE_UINT8, 8, data), )
        print '    Priority level: %s' % (oumanSerial.convertOumanMessage(oumanSerial.TYPE_UINT8, 9, data), )
        print '    Index: %s' % (oumanSerial.convertOumanMessage(oumanSerial.TYPE_UINT16, 10, data), )
        print '    Value: %s' % (oumanSerial.convertOumanMessage(oumanSerial.TYPE_UINT32, 12, data), )
        print '    Year: %s' % (oumanSerial.convertOumanMessage(oumanSerial.TYPE_UINT16, 16, data), )
        print '    Month: %s' % (oumanSerial.convertOumanMessage(oumanSerial.TYPE_UINT8, 18, data), )
        print '    Day: %s' % (oumanSerial.convertOumanMessage(oumanSerial.TYPE_UINT8, 19, data), )
        print '    Hour: %s' % (oumanSerial.convertOumanMessage(oumanSerial.TYPE_UINT8, 20, data), )
        print '    Minute: %s' % (oumanSerial.convertOumanMessage(oumanSerial.TYPE_UINT8, 21, data), )
        print '    Second: %s' % (oumanSerial.convertOumanMessage(oumanSerial.TYPE_UINT8, 22, data), )
        print '    Millisecond: %s' % (oumanSerial.convertOumanMessage(oumanSerial.TYPE_UINT16, 23, data), )
        print '    Alarm limit: %s' % (oumanSerial.convertOumanMessage(oumanSerial.TYPE_UINT32, 24, data), )

            
def Usage():
    print 'USAGE:  python oumanGetData.py --help'
    print '        python oumanGetData.py [-v] <serialDev> <id>'


def Help():
    temps = string.split(HELP_TEXT, '\n')
    for temp in temps:
        if len(temp) > 0 and temp[0] == '#':
            temp = temp[1:]
        if len(temp) > 0 and temp[0] == ' ':
            temp = temp[1:]
        print temp
 

###########################################################################

if __name__ == "__main__":
  main()
