#!env python
# -*- coding: iso-8859-1 -*-
###########################################################################
# 
# File:            oumanSetParameter.py
#
#
# Licence:         Donationware, distributed as Freeware
#
#                  If you find this software useful to you and you would
#                  like to help the developer to maintain it also in the future, 
#                  please donate a small amount of your liking to the 
#                  PayPal account: olammi@iki.fi.
#
#                  This donation is not required to use the software and the 
#                  software is licenced as freeware.
#
#                  To individual and non-commercial use only! Script
#                  and source code may be used freely for non-commercial
#                  purposes. Any commercial usage requires permission or
#                  licence from the author. 
#
#
HELP_TEXT = """
# DISCLAIMER:      You can use this software to configure your controller 
#                  equipment. The author of this software is not in any way
#                  responsible for possible configuration errors or the 
#                  parameter values this software writes to the controller. 
#                  The software user must read thoroughly this document,
#                  be sure to enter valid configuration values and accept 
#                  the fact that the software author is not responsible 
#                  of your configuration. USE THIS SOFTWARE AT YOUR OWN RISK.
#
# Usage:           python oumanSetParameter.py --help
#                  python oumanSetParameter.py [-v] <serialDev> <oumanDevice> <parameter> <value>
#
#                  Options (options override the configuration file):
#                    --help      - Prints out a help and exits.
#
#                    -v          - Enable debug/verbose logging.
#
#                  Parameters:
#                    serialDev   - Path to serial device (eg. /dev/ttyS0)
#
#                    oumanDevice - ID of the Ouman device type (eg. EH202S)
#
#                    parameter   - Key of the parameter (eg. AlaMin)
#
#                    value       - New value for the parameter
#
#                  Examples:
#                    [taloLogger]% python ./oumanSetParameter.py /dev/ttyS0 EH202S AlaMin 32
#                    [taloLogger]%   
#
"""
#
# Author:          Olli Lammi (olammi@iki.fi)
#
# Version:         1.0a
#
# Date:            17.08.2010
#
# Functions:       -
#                   
# Description:     Script to set Ouman parameters using
#                  the serial connection to Ouman controller.
#
# Requirements:    Python interpreter 2.4 or newer (www.python.org)
#                  (tested with 2.4.4)
# 
#                  For Ouman controller communications:
#                    Python Serial Port Extension: pySerial  
#                    (http://pyserial.wiki.sourceforge.net/pySerial)
#
# Version history: ** 17.08.2010 v1.0a (Olli Lammi) **
#                  First beta version for testers. 
#
###########################################################################

# Imports

import sys, os 
import string  

import configuration
import oumanSerial
import log


####### main ##########################################################

def main():
    verbose = 0
    serial_port = ''
    ouman_device = ''
    ouman_key = ''
    value = ''

    # handle command line parameters
    i = 1
    j = 0
    while i < len(sys.argv):
        if sys.argv[i] == '--help':
            Help()
            sys.exit(1)
        elif sys.argv[i] == '-v':
            verbose = 1
        elif j == 0:
            serial_port = sys.argv[i]
            j = j + 1
        elif j == 1:
            ouman_device = sys.argv[i]
            j = j + 1
        elif j == 2:
            ouman_key = sys.argv[i]
            j = j + 1
        elif j == 3:
            value = sys.argv[i]
            j = j + 1
        else:
            Usage()
            sys.exit(1)

        i = i + 1
        
    if len(serial_port) <= 0 or len(ouman_device) <= 0 or \
       len(ouman_key) <= 0 or len(value) <= 0:
        Usage()
        sys.exit(1) 


    conf = configuration.Configuration()
    conf.addConfigurable(log.Logger)
    conf.setValue('CONSOLE_LOGGING', 'true')
    if verbose:
        conf.setValue('VERBOSE_LOGGING', 'true')
    LOG = log.Logger(conf)
    log.Logging.setLogger(LOG)

    oser = oumanSerial.OumanSerial(serial_port, ouman_device)

    data = oser.runSetCommand(ouman_key, value)
    if len(data) <= 0 or data != 'OK':
        LOG.log("ERROR: Cannot set parameter to Ouman device.")
        sys.exit(1)
          
  
def Usage():
    print 'USAGE:  python oumanSetParameter.py --help'
    print '        python oumanSetParameter.py [-v] <serialDev> <oumanDevice> <parameter> <value>'


def Help():
    temps = string.split(HELP_TEXT, '\n')
    for temp in temps:
        if len(temp) > 0 and temp[0] == '#':
            temp = temp[1:]
        if len(temp) > 0 and temp[0] == ' ':
            temp = temp[1:]
        print temp
 

###########################################################################

if __name__ == "__main__":
  main()