#!env python
# -*- coding: iso-8859-1 -*-
###########################################################################
# 
# File:            storeDb.py
#
# Licence:         Donationware, distributed as Freeware
#
#                  If you find this software useful to you and you would
#                  like to help the developer to maintain it also in the future, 
#                  please donate a small amount of your liking to the 
#                  PayPal account: olammi@iki.fi.
#
#                  This donation is not required to use the software and the 
#                  software is licenced as freeware.
#
#                  To individual and non-commercial use only! Script
#                  and source code may be used freely for non-commercial
#                  purposes. Any commercial usage requires permission or
#                  licence from the author. 
#
# Author:          Olli Lammi (olammi@iki.fi)
#
# Version:         1.0c
#
# Date:            10.02.2011
#
# Description:     Data Store class to store logged data values into a
#                  MySql database.
#                  
# Requirements:    Python interpreter 2.4 or newer (www.python.org)
#                  (tested with 2.4.3)
# 
#                  MySQL-python library (MySQLdb) 
#                  (http://sourceforge.net/projects/mysql-python)
#
# Version history: ** 24.02.2009 v0.9a (Olli Lammi) **
#                  First beta version for testers. 
#
#                  ** 25.02.2009 v0.9c (Olli Lammi) **
#                  Logging and import changes 
#
#                  ** 03.03.2009 v0.9e (Olli Lammi) **
#                  Class hierarchy changes. 
#
#                  ** 06.04.2009 v1.0a (Olli Lammi) **
#                  Changed to support configurable init. 
#
#                  ** 20.11.2010 v1.0b (Olli Lammi) **
#                  Added commit to insert fucntion. 
#
#                  ** 10.02.2011 v1.0c (Olli Lammi) **
#                  Interface changes. 
#
###########################################################################

# Imports

import sys, os 
import string

import store, configuration
import log

# MySQLdb module, not loaded until init of DBStore class instance
MySQLdb = None

###########################################################################

# Classes

class DBStore(store.Store, configuration.Configurable, log.Logging):
    def __init__(self, conf, modname):
        log.Logging.__init__(self, modname)
        self.setModuleName(modname)

        global MySQLdb
        MySQLdb = __import__('MySQLdb') 

        self.handleConfiguration(conf)

    def handleConfiguration(self, conf):
        self.DB_HOST = conf.getValue('HOST', '', self.getModuleName())
        self.DB_USER = conf.getValue('USER', '', self.getModuleName())
        self.DB_PASSWD = conf.getValue('PASSWD', '', self.getModuleName())
        self.DB_NAME = conf.getValue('NAME', '', self.getModuleName())
        self.DB_TABLE = conf.getValue('TABLE', '', self.getModuleName())
        self.DB_TIMECOL = conf.getValue('TIMECOL', '', self.getModuleName())        
        return (1, '')

    def initConfiguration(self):
        status = 0
        sqlstmt = ""
        try:
            db = MySQLdb.connect(host=self.DB_HOST, user=self.DB_USER, \
                                 passwd=self.DB_PASSWD, db=self.DB_NAME)
            cur = db.cursor()
            sqlstmt = "SELECT COUNT(" + self.DB_TIMECOL + ") FROM " + self.DB_TABLE
            cur.execute(sqlstmt)
            cur.close()
            db.close()
            status = 1
        except:
            self.Log("ERROR: Error in database operation, SQL: " + sqlstmt)
            status = 0
        if status:
            return (1, '')
        else:
            return (0, 'DBStore: Errors with database access.')

 
    def insertData(self, values):
        sqlstmt = ""
        try:
            db = MySQLdb.connect(host=self.DB_HOST, user=self.DB_USER, \
                                 passwd=self.DB_PASSWD, db=self.DB_NAME)
            cur = db.cursor()

            columnstr = ""
            valuestr = ""
            for item in values:
                if len(columnstr) > 0:
                    columnstr = columnstr + ", "
                if len(valuestr) > 0:
                    valuestr = valuestr + ", "
                columnstr = columnstr + item[0]
                valuestr = valuestr + checkDBValue(item[1])
                
            sqlstmt = "INSERT INTO " + self.DB_TABLE + " "
            sqlstmt = sqlstmt + "(" + self.DB_TIMECOL + ", "
            sqlstmt = sqlstmt + columnstr + ") VALUES (now(), "
            sqlstmt = sqlstmt + valuestr + ")"

            self.Debug("Inserting data to database using SQL: " + sqlstmt)
            cur.execute(sqlstmt)
            cur.close()
            db.commit()
            db.close()
        except:
            self.Log("ERROR: Error in database operation, SQL: " + sqlstmt)

    @staticmethod
    def getAllowedConfigurationKeys():
        return (['HOST', 'USER', 'PASSWD', 'NAME', 'TABLE', 'TIMECOL'], [])


###########################################################################

# Functions

def checkDBValue(val):
    if (val and len(val) > 0):
        return val
    return "NULL"

