#!env python
# -*- coding: iso-8859-1 -*-
###########################################################################
# 
# File:            storeRrd.py
#
# Licence:         Donationware, distributed as Freeware
#
#                  If you find this software useful to you and you would
#                  like to help the developer to maintain it also in the future, 
#                  please donate a small amount of your liking to the 
#                  PayPal account: olammi@iki.fi.
#
#                  This donation is not required to use the software and the 
#                  software is licenced as freeware.
#
#                  To individual and non-commercial use only! Script
#                  and source code may be used freely for non-commercial
#                  purposes. Any commercial usage requires permission or
#                  licence from the author. 
#
# Author:          Olli Lammi (olammi@iki.fi)
#
# Version:         1.0b
#
# Date:            10.02.2011
#
# Description:     Data Store class to store logged data values into a
#                  rrd database.
#                  
# Requirements:    Python interpreter 2.4 or newer (www.python.org)
#                  (tested with 2.4.4)
# 
# Version history: ** 24.02.2009 v0.9b (Olli Lammi) **
#                  First version. 
#
#                  ** 25.02.2009 v0.9c (Olli Lammi) **
#                  Logging changes. Changed not to use rrdtool library
#                  because it requires external lib.  
#
#                  ** 06.04.2009 v1.0a (Olli Lammi) **
#                  Changed to support configurable init. 
#
#                  ** 10.02.2011 v1.0b (Olli Lammi) **
#                  Interface changes. 
#
###########################################################################

# Imports

import sys, os 
import string, time
import subprocess

import store, configuration, log


###########################################################################

# Classes

class RrdStore(store.Store, configuration.Configurable, log.Logging):
    def __init__(self, conf, modname):
        log.Logging.__init__(self, modname)
        self.setModuleName(modname)
        self.handleConfiguration(conf)

    def handleConfiguration(self, conf):
        self.RRDTOOL = conf.getValue('RRDTOOL_LOCATION', '', self.getModuleName())
        self.DB_FNAME = conf.getValue('DB_FILENAME', '', self.getModuleName())
        return (1, '')

    def initConfiguration(self):
        # check the existence of the RRDtool
        if not os.access(self.RRDTOOL, os.X_OK):
            return (0, 'RrdStore: Unable to find or execute RRDTool executable: ' + self.RRDTOOL)
        if not os.access(self.DB_FNAME, os.W_OK):
            return (0, 'RrdStore: Unable to find rrd db file or it is not writable: ' + self.DB_FNAME)
        return (1, '')

    def insertData(self, values):
        templatestr = ''
        valuestr = 'N'
        for item in values:
            if len(templatestr) > 0:
                templatestr = templatestr + ':'
            templatestr = templatestr + string.strip(item[0])
            valuestr = valuestr + ':' + string.strip(item[1])
            
        rrdtoolcmd = self.RRDTOOL + ' update ' + self.DB_FNAME + ' -t ' + templatestr + ' ' + valuestr
        self.Debug("Inserting data to rrd database: " + self.DB_FNAME + " using command: " + rrdtoolcmd)
        stat = -1
        output = ['', '']
        try:      
            sb = subprocess.Popen(rrdtoolcmd, shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
            output = sb.communicate()
            stat = sb.returncode
        except:
            stat = -1
        if stat != 0:
            temps = "ERROR: Error writing data store RRD database: " + self.DB_FNAME + "\n"
            temps = temps + "  RRDTool command: " + rrdtoolcmd + "\n"
            temps = temps + "  RRDTool output: " + output[0] + output[1]
            self.Log(temps)                
        
    @staticmethod
    def getAllowedConfigurationKeys():
        return (['RRDTOOL_LOCATION', 'DB_FILENAME'], [])
